@@ -24,7 +24,7 @@ from mmocr.apis.inference import model_inference
 from mmocr.models.builder import DETECTORS as mmocr_models
 from nptyping import Int, NDArray, Shape
 
-from mlcvzoo_mmocr.configuration import MMOCRConfig
+from mlcvzoo_mmocr.configuration import MMOCRConfig, MMOCRInferenceConfig
 from mlcvzoo_mmocr.mlcvzoo_mmocr_dataset import MLCVZooMMOCRDataset
 from mlcvzoo_mmocr.third_party.mmocr import build_val_dataset
 
@@ -38,10 +38,10 @@ mmocr_models.module_dict.update(mmocr_models.parent.module_dict)
 ImageType = NDArray[Shape["Height, Width, Any"], Int]
 
 
-class MMOCRModel(MMDetectionModel, ABC, Generic[PredictionType]):
+class MMOCRModel(MMDetectionModel[MMOCRInferenceConfig], ABC, Generic[PredictionType]):
     def __init__(
         self,
-        from_yaml: str,
+        from_yaml: Optional[str] = None,
         configuration: Optional[MMOCRConfig] = None,
         string_replacement_map: Optional[Dict[str, str]] = None,
         init_for_inference: bool = False,
