@@ -29,7 +29,7 @@ class MMOCRTextRecognitionModel(
 ):
     def __init__(
         self,
-        from_yaml: str,
+        from_yaml: Optional[str] = None,
         configuration: Optional[MMOCRConfig] = None,
         string_replacement_map: Optional[Dict[str, str]] = None,
         init_for_inference: bool = False,
@@ -45,7 +45,6 @@ class MMOCRTextRecognitionModel(
         )
         OCRModel.__init__(
             self,
-            unique_name=self.configuration.base_config.MODEL_SPECIFIER,
             configuration=self.configuration,
             init_for_inference=init_for_inference,
         )
